@@ -312,19 +312,19 @@ class CVHoughDetector:
             print(f"YOLO检测失败: {e}")
             return []
 
-    def detect_circles_in_object_boxes(self, image_path):
+    def detect_circles_in_object_boxes(self, image_path, visualize=True, gray_threshold=0.5):
         """
         先用YOLO模型识别物体，然后在每个物体框内检测灰色圆
         
         参数:
             image_path: 图像文件路径
+            visualize: 是否可视化结果（保存图片）
+            gray_threshold: 灰色像素百分比阈值
             
         返回:
             dict: 每个物体框内检测到的圆形 {object_id: [(center_x, center_y, radius, circularity, gray_percentage), ...]}
         """
-        # 使用与main.py完全相同的默认参数
-        visualize = True
-        gray_threshold = 0.5
+        # 使用传入的参数
         total_start_time = time.time()
         
         # 读取图像
@@ -568,13 +568,11 @@ class CVHoughDetector:
                             cv2.putText(retained_gray_circles_image, gray_text, (center_x - 20, center_y + radius + 45),
                                         cv2.FONT_HERSHEY_SIMPLEX, font_scale * 0.6, (128, 128, 128), line_thickness, cv2.LINE_AA)
             
-            # 只显示保留的灰色圆图像
+            # 保存检测结果图像而不是显示
+            output_path = os.path.splitext(image_path)[0] + "_detected_circles.jpg"
             display_img = self.resize_for_display(retained_gray_circles_image, max_width=800, max_height=600)
-            cv2.imshow("保留的灰色圆", display_img)
-            
-            print("按任意键关闭窗口...")
-            cv2.waitKey(0)
-            cv2.destroyAllWindows()
+            cv2.imwrite(output_path, display_img)
+            print(f"检测结果已保存到: {output_path}")
         
         return object_circles
 
