@@ -30,8 +30,8 @@ def detect_gray_circles(image_path):
     # 创建检测器实例
     detector = CVHoughDetector(model_path=model_path)
     
-    # 使用main.py中的默认参数调用检测函数
-    return detector.detect_circles_in_object_boxes(image_path)
+    # 使用main.py中的默认参数调用检测函数，启用可视化以保存图片
+    return detector.detect_circles_in_object_boxes(image_path, visualize=True)
 
 
 __all__ = ['detect_gray_circles']
\ No newline at end of file
